@@ -14,12 +14,10 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import sys
 import struct
-import hashlib
 import os
 import time
-from binascii import hexlify, unhexlify
+from binascii import hexlify
 from xml.etree import cElementTree as ET
 import logging
 logger = logging.getLogger('pasaffe_lib')
