@@ -17,7 +17,6 @@
 """Helpers for an Ubuntu application."""
 import logging
 import os
-import sys
 import subprocess
 
 from . pasaffeconfig import get_data_file
@@ -284,7 +283,7 @@ def field_to_folder_list(field):
 
 def folder_list_to_path(folders, index=None):
     '''Converts a folder list to a folder path'''
-    if len(folders) is 0 or folders is None:
+    if len(folders) == 0 or folders is None:
         return "/"
 
     if index is None:
@@ -352,9 +351,6 @@ def confirm(prompt=None, resp=False):
 
     """
 
-    if options.yes:
-        return resp
-
     if prompt is None:
         prompt = 'Confirm'
 
@@ -396,7 +392,7 @@ def gen_password(number, size):
                "-x", str(size)]
     try:
         passwords = subprocess.check_output(command).splitlines()
-    except:
+    except:  # noqa: E722
         print(_("error running apg"))
         passwords = None
     return passwords
