@@ -35,18 +35,18 @@ class TestReadDB(unittest.TestCase):
 
         folder_list = [[[], ""],
                        [["foldera"], "foldera"],
-                       [["folder.a"], "folder\.a"],  # noqa: W605
-                       [["foldera."], "foldera\."],  # noqa: W605
-                       [[".foldera"], "\.foldera"],  # noqa: W605
+                       [["folder.a"], r"folder\.a"],
+                       [["foldera."], r"foldera\."],
+                       [[".foldera"], r"\.foldera"],
                        [["foldera.", "folderb."],
-                         "foldera\..folderb\."],  # noqa: W605
+                        r"foldera\..folderb\."],
                        [["foldera", "folderb"], "foldera.folderb"],
                        [["folder.a", "folderb"],
-                         "folder\.a.folderb"],  # noqa: W605
-                       [["foldera", "folder.b"], "foldera.folder\.b"],
-                       [["folder.a", "folder.b"], "folder\.a.folder\.b"],
+                        r"folder\.a.folderb"],
+                       [["foldera", "folder.b"], r"foldera.folder\.b"],
+                       [["folder.a", "folder.b"], r"folder\.a.folder\.b"],
                        [["folder.a", "folder.b", "folder.c"],
-                        "folder\.a.folder\.b.folder\.c"],
+                        r"folder\.a.folder\.b.folder\.c"],
                        [["", "foldera", "folderb"], ".foldera.folderb"],
                        [["", "", "folderb"], "..folderb"],
                        [["foldera", "", "folderb"], "foldera..folderb"],
@@ -61,16 +61,16 @@ class TestReadDB(unittest.TestCase):
 
         folder_list = [["", []],
                        ["foldera", ["foldera"]],
-                       ["folder\.a", ["folder.a"]],  # noqa: W605
-                       ["foldera\.", ["foldera."]],  # noqa: W605
-                       ["\.foldera", [".foldera"]],  # noqa: W605
-                       ["foldera\..folderb\.",
-                        ["foldera.", "folderb."]],  # noqa: W605
+                       [r"folder\.a", ["folder.a"]],
+                       [r"foldera\.", ["foldera."]],
+                       [r"\.foldera", [".foldera"]],
+                       [r"foldera\..folderb\.",
+                        ["foldera.", "folderb."]],
                        ["foldera.folderb", ["foldera", "folderb"]],
-                       ["folder\.a.folderb", ["folder.a", "folderb"]],
-                       ["foldera.folder\.b", ["foldera", "folder.b"]],
-                       ["folder\.a.folder\.b", ["folder.a", "folder.b"]],
-                       ["folder\.a.folder\.b.folder\.c",
+                       [r"folder\.a.folderb", ["folder.a", "folderb"]],
+                       [r"foldera.folder\.b", ["foldera", "folder.b"]],
+                       [r"folder\.a.folder\.b", ["folder.a", "folder.b"]],
+                       [r"folder\.a.folder\.b.folder\.c",
                        ["folder.a", "folder.b", "folder.c"]],
                        [".foldera.folderb", ["", "foldera", "folderb"]],
                        ["..folderb", ["", "", "folderb"]],
@@ -104,7 +104,7 @@ class TestReadDB(unittest.TestCase):
         self.assertEqual(len(uuid_hex), 32)
         self.assertTrue(uuid_hex in self.passfile.records)
 
-        for field in [1, 3, 4, 5, 6, 7, 8, 12, 13]:
+        for field in [1, 3, 4, 5, 6, 7, 8, 12, 13, 20]:
             self.assertTrue(field in self.passfile.records[uuid_hex])
 
     def test_delete_entry(self):
@@ -197,6 +197,17 @@ class TestReadDB(unittest.TestCase):
         url = self.passfile.get_url(uuid_hex)
         self.assertTrue(url == test_url)
 
+    def test_get_email(self):
+
+        self.passfile.new_db("test")
+        uuid_hex = self.passfile.new_entry()
+
+        test_email = "test@example.com"
+        self.passfile.records[uuid_hex][20] = test_email
+
+        email = self.passfile.get_email(uuid_hex)
+        self.assertTrue(email == test_email)
+
     def test_update_folder_list(self):
 
         self.passfile.new_db("test")
